"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const flags = require("@oclif/command/lib/flags");
const path = require("path");
const core_1 = require("./core");
const conf_1 = require("./services/conf");
const logger_1 = require("./services/logger");
class Base extends command_1.Command {
    constructor() {
        super(...arguments);
        this.verbose = false;
        this.quickRun = false;
        this.watch = false;
    }
    get mustachesDir() {
        return path.resolve(__dirname, 'mustaches');
    }
    get frameworks() {
        return conf_1.default.frameworks;
    }
    getCoreInstance(options) {
        return new core_1.default(options);
    }
    async init() {
        // @ts-ignore
        const { flags } = this.parse(this.constructor);
        this.verbose = flags.verbose;
        this.quickRun = flags.quickRun;
        this.watch = flags.watch;
        // check user input args here
        const args = await this.preInit();
        logger_1.logger.info('Phase 1: Start initializing');
        // initialize everything needed here
        await this.initialize(args);
        logger_1.logger.info('Phase 2: Preparing');
        // prepare running context here
        await this.preRun();
        logger_1.logger.info('Phase 3: Start running');
    }
    async catch(e) {
        logger_1.logger.error(e.message);
        this.exit(1);
    }
    async finally(e) {
        if (!e) {
            await this.postRun();
        }
    }
    async preInit() { }
    async initialize(_args) { }
    async preRun() { }
    async postRun() { }
}
Base.flags = {
    verbose: flags.boolean({ char: 'v', required: false, description: 'show verbose logs' }),
    quickRun: flags.boolean({ char: 'q', required: false, description: 'skip prepare runtime, run cmd immediately' }),
    watch: flags.boolean({ char: 'w', required: false, description: 'watch file change when run script' })
};
exports.default = Base;
